@@ -16,8 +16,11 @@ impute_artifacts_wrapper <- function(impute_artifacts, clean_artifacts,
                     .sample_id <- unique(sample_id[missing_rel])
                     samples_for_imputation <- sample_id %in% .sample_id
                     
-                    if(!is.null(categorical_moderators))
+                    if(!is.null(categorical_moderators)){
                          .categorical_moderators <- data.frame(as_tibble(categorical_moderators)[samples_for_imputation,])
+                    }else{
+                         .categorical_moderators <- NULL
+                    }
                     
                     rel_imputed <- impute_artifact_2col(logic_vec_x = data_x$rxx_restricted[samples_for_imputation],
                                                         logic_vec_y = data_y$ryy_restricted[samples_for_imputation],
